<?php

/**
 * @package LocationsAndAreasPlugin
 */
namespace LocationsAndAreasPlugin\Pages;

use  LocationsAndAreasPlugin\Base\BaseController ;
class Frontend extends BaseController
{
    public function register()
    {
        // Shortcodes
        add_action( 'init', array( $this, 'set_shortcodes' ) );
        // Gutenberg Blocks
        add_action( 'init', array( $this, 'set_gutenberg_blocks' ) );
    }
    
    /**
     * Setup Shortcode
     */
    public function set_shortcodes()
    {
        add_shortcode( 'locations-and-areas-map', array( $this, 'render_block_map' ) );
    }
    
    /**
     * Setup Gutenberg Blocks
     */
    public function set_gutenberg_blocks()
    {
        // register JS for Gutenberg Blocks
        $asset_file = (include $this->plugin_path . 'blocks/build/index.asset.php');
        wp_register_script(
            'locationsandareas_blocks_script',
            $this->plugin_url . 'blocks/build/index.js',
            $asset_file['dependencies'],
            $asset_file['version']
        );
        // Register Block: Locations and Areas Map
        register_block_type( 'locations-and-areas/map', array(
            'api_version'     => 2,
            'editor_script'   => 'locationsandareas_blocks_script',
            'render_callback' => ( is_admin() ? null : array( $this, 'render_block_map' ) ),
        ) );
        // add JS translation for Gutenberg Blocks script
        /*
        Pay Attention: 
        - currently doesnt work with wordpress.org translation --> use local translation file 
        - Translation file needs to be called "locations-and-areas-de_DE-locationsandareas_blocks_script.json"
        - Howto: https://developer.wordpress.org/block-editor/how-to-guides/internationalization/
        */
        wp_set_script_translations( 'locationsandareas_blocks_script', 'locations-and-areas', $this->plugin_path . 'languages' );
    }
    
    /**
     * Render the map
     */
    public function render_block_map( $block_attributes, $content )
    {
        // error_log(print_r($block_attributes, true));
        // error_log(print_r($content, true));
        ob_start();
        wp_enqueue_style(
            'laa_frontend_css',
            $this->plugin_url . 'assets/frontend.css',
            array(),
            $this->plugin_version
        );
        wp_enqueue_style(
            'laa_leaflet_css',
            $this->plugin_url . 'src/leaflet/leaflet.css',
            array(),
            $this->plugin_version
        );
        wp_enqueue_style(
            'laa_leaflet_gesture_css',
            $this->plugin_url . 'src/leaflet/leaflet-gesture-handling.min.css',
            array(),
            $this->plugin_version
        );
        wp_enqueue_style(
            'laa_leaflet_markercluster_css',
            $this->plugin_url . 'src/leaflet/leaflet-markercluster.css',
            array(),
            $this->plugin_version
        );
        wp_enqueue_style(
            'laa_leaflet_markercluster_default_css',
            $this->plugin_url . 'src/leaflet/leaflet-markercluster.default.css',
            array(),
            $this->plugin_version
        );
        wp_enqueue_script(
            'laa_leaflet_js',
            $this->plugin_url . 'src/leaflet/leaflet.js',
            array(),
            $this->plugin_version
        );
        wp_enqueue_script(
            'laa_leaflet_providers_js',
            $this->plugin_url . 'src/leaflet/leaflet-providers.js',
            array( 'laa_leaflet_js' ),
            $this->plugin_version
        );
        wp_enqueue_script(
            'laa_leaflet_gesture_js',
            $this->plugin_url . 'src/leaflet/leaflet-gesture-handling.min.js',
            array( 'laa_leaflet_js' ),
            $this->plugin_version
        );
        wp_enqueue_script(
            'laa_leaflet_markercluster_js',
            $this->plugin_url . 'src/leaflet/leaflet-markercluster.js',
            array( 'laa_leaflet_js' ),
            $this->plugin_version
        );
        require_once "{$this->plugin_path}/templates/block-map.php";
        wp_enqueue_script(
            'laa_frontend_block_map_js',
            $this->plugin_url . 'src/js/frontend-block-map.js',
            array( 'laa_leaflet_providers_js', 'laa_leaflet_gesture_js', 'laa_leaflet_markercluster_js' ),
            $this->plugin_version
        );
        return ob_get_clean();
    }
    
    /**
     * [PRO] Add location from frontend (AJAX)
     */
    public function ajax_add_location_from_frontend()
    {
    }

}